# Changelog

## [0.7.0](https://github.com/uptick/datawarehouse/compare/v0.6.0...v0.7.0) (2025-09-05)


### Features

* **rollforward:** add price increase upgrade or downgrade ([c363194](https://github.com/uptick/datawarehouse/commit/c363194965dd355104dc67270e45f113b477ca62))

## [0.6.0](https://github.com/uptick/datawarehouse/compare/v0.5.0...v0.6.0) (2025-08-29)


### Features

* **rollforward:** add new columns ([6a17f73](https://github.com/uptick/datawarehouse/commit/6a17f739af75f56d45a84b553c3c21f877196aed))
* **rollforward:** add new columns ([e5a9718](https://github.com/uptick/datawarehouse/commit/e5a97185b2140bbbac380aa8f7deacc1c23c2015))

## [0.4.0](https://github.com/uptick/datawarehouse/compare/v0.3.1...v0.4.0) (2025-07-04)


### Features

* **subman:** add FixedFXRate table ([ee9914d](https://github.com/uptick/datawarehouse/commit/ee9914d7688d41a77845befb871c8a5c302866ae))
* **subman:** add InvoiceLineItem table ([7d1293d](https://github.com/uptick/datawarehouse/commit/7d1293db9ee856bccdbcee072349a4dae8492d89))


### Bug Fixes

* add missing Meta for invoice lineitems ([169c626](https://github.com/uptick/datawarehouse/commit/169c6267f5a7e7c115838e982dd02c968a23307f))
* hide my wrongdoings ([188798a](https://github.com/uptick/datawarehouse/commit/188798ac39ac4869324607395a56eb8435c21199))

## [0.3.1](https://github.com/uptick/datawarehouse/compare/v0.3.0...v0.3.1) (2025-07-01)


### Bug Fixes

* **xero:** allow nullable invoice reference ([5fa6c94](https://github.com/uptick/datawarehouse/commit/5fa6c9426e9874228377763a00d334de121b4fad))

## [0.3.0](https://github.com/uptick/datawarehouse/compare/0.2.36...v0.3.0) (2025-06-04)


### Features

* **rollforward:** add product expansion to rollforward ([948010a](https://github.com/uptick/datawarehouse/commit/948010a363990d98163666098fa5be10aef1a803))
* **subscriptionmanager:** add original subscription fields to summary ([b15594f](https://github.com/uptick/datawarehouse/commit/b15594feecbeb118e9e6974243d01875e7edf23b))
* **workforce:** add new server usage model ([7abddab](https://github.com/uptick/datawarehouse/commit/7abddab0a1e222dbe280fa56f29e179811923799))


### Bug Fixes

* **datawarehouse:** fix wording on ServerUsageMetric model ([ae12fc8](https://github.com/uptick/datawarehouse/commit/ae12fc8514d883592934b18b83fd3b332fcbf394))

## [0.2.32](https://github.com/uptick/datawarehouse/compare/0.2.31...v0.2.32) (2025-02-26)


### Bug Fixes

* **accounts:** fix datawarehouse models ([dd9a2a1](https://github.com/uptick/datawarehouse/commit/dd9a2a1310638e81f07a50dfcbbe2286a978d5d5))
